@@ -28,29 +28,36 @@ from .geometry import GeometryModel
 logger = colorlog.getLogger('PySimultan')
 
 
-class IAuthenticationServiceNew(IAuthenticationService):
-    __namespace__ = "authenticate_namespace"
+def create_IAuthenticationService(user_name, password):
 
-    def Authenticate(self, user_manager, project_file):
-        user_name = 'admin'
-        password = 'admin'
+    class IAuthenticationServiceNew(IAuthenticationService):
+        __namespace__ = "authenticate_namespace"
 
-        sec_str = SecureString()
-        for char in password:
-            sec_str.AppendChar(char)
+        def Authenticate(self, user_manager, project_file):
+            # user_name = 'admin'
+            # password = 'admin'
 
-        user = user_manager.Authenticate(user_name, sec_str)
+            sec_str = SecureString()
+            for char in password:
+                sec_str.AppendChar(char)
 
-        user_manager.CurrentUser = user.Item1
-        user_manager.EncryptionKey = user.Item2
+            user = user_manager.Authenticate(user_name, sec_str)
 
-        return user.Item1
+            user_manager.CurrentUser = user.Item1
+            user_manager.EncryptionKey = user.Item2
+
+            return user.Item1
+
+    return IAuthenticationServiceNew
 
 
 class DataModel:
 
     def __init__(self, *args, **kwargs):
 
+        self.user_name = kwargs.get('user_name', 'admin')
+        self.password = kwargs.get('password', 'admin')
+
         atexit.register(self.cleanup)
 
         self.id = uuid4()
@@ -64,7 +71,10 @@ class DataModel:
         # self.user = kwargs.get('user', ComponentManagerType.ADMINISTRATOR)
 
         self.service_provider = ServicesProvider()
-        self.get_service_provider().AddService[IAuthenticationService](IAuthenticationServiceNew())
+
+        i_aut_service = create_IAuthenticationService(self.user_name, self.password)
+
+        self.get_service_provider().AddService[IAuthenticationService](i_aut_service())
         # self.zip_loader = ZipProjectIO(self.service_provider)
 
         _ = self.project
