@@ -5,7 +5,7 @@ import colorlog
 # from functools import lru_cache
 from tqdm import tqdm
 from .utils import classproperty
-from .geo_default_types import geometry_types
+from .geo_default_types import create_geo_classes
 
 
 logger = colorlog.getLogger('PySimultan')
@@ -178,59 +178,73 @@ class GeometryModel(object):
         logger.info(f'Number volumes: {self.volumes.__len__()}\n\n')
 
     def get_geo_components(self, geo):
+        """
+        Get the simultan components linked to the geometric instance
+        :param geo: geometry instance of type BaseGeoBaseClass
+        :return: simultan components
+        """
         return self.template_parser.get_geo_components(geo)
 
+    def get_py_geo_components(self, geo, template_name=None):
+        """
 
-def create_geo_classes(geo_types):
-    """
-    Create new classes from geometric base classes
+        :param geo: geometry instance of type BaseGeoBaseClass
+        :param template_name: name of the template which should be used to create the component; if None suiting template is found automatically; default: None
+        :return: python typed components
+        """
+        return self.template_parser.get_py_geo_components(geo, template_name=template_name)
 
-    :return:
-    """
 
-    logger.debug('creating base geo classes')
-
-    class GeoBaseClass(geo_types['base']):
-        pass
-
-    class GeometricLayer(geo_types['layer']):
-        pass
-
-    class GeometricVertex(geo_types['vertex']):
-        pass
-
-    class GeometricEdge(geo_types['edge']):
-        def get_vertices(self):
-            return [GeometricVertex.get_obj_by_id(x.Id) for x in self._wrapped_obj.Vertices.Items]
-
-    class GeometricEdgeLoop(geo_types['edge_loop']):
-        def get_edges(self):
-            return [GeometricEdge.get_obj_by_id(x.Edge.Id) for x in self._wrapped_obj.Edges.Items]
-
-    class GeometricFace(geo_types['face']):
-
-        @property
-        def boundary(self):
-            return GeometricEdgeLoop.get_obj_by_id(self._wrapped_obj.Boundary.Id)
-
-        @property
-        def holes(self):
-            return [GeometricEdgeLoop.get_obj_by_id(x.Id) for x in self._wrapped_obj.Holes.Items]
-
-        @property
-        def points(self):
-            return self.boundary.points
-
-    class GeometricVolume(geo_types['volume']):
-
-        @property
-        def faces(self):
-            if self._faces is None:
-                self._faces = [GeometricFace.get_obj_by_id(x.Face.Id) for x in self._wrapped_obj.Faces.Items]
-            return self._faces
-
-        @faces.setter
-        def faces(self, value):
-            self._faces = value
-
-    return GeoBaseClass, GeometricLayer, GeometricVertex, GeometricEdge, GeometricEdgeLoop, GeometricFace, GeometricVolume
+# def create_geo_classes(geo_types):
+#     """
+#     Create new classes from geometric base classes
+#
+#     :return:
+#     """
+#
+#     logger.debug('creating base geo classes')
+#
+#     class GeoBaseClass(geo_types['base']):
+#         pass
+#
+#     class GeometricLayer(geo_types['layer']):
+#         pass
+#
+#     class GeometricVertex(geo_types['vertex']):
+#         pass
+#
+#     class GeometricEdge(geo_types['edge']):
+#         def get_vertices(self):
+#             return [GeometricVertex.get_obj_by_id(x.Id) for x in self._wrapped_obj.Vertices.Items]
+#
+#     class GeometricEdgeLoop(geo_types['edge_loop']):
+#         def get_edges(self):
+#             return [GeometricEdge.get_obj_by_id(x.Edge.Id) for x in self._wrapped_obj.Edges.Items]
+#
+#     class GeometricFace(geo_types['face']):
+#
+#         @property
+#         def boundary(self):
+#             return GeometricEdgeLoop.get_obj_by_id(self._wrapped_obj.Boundary.Id)
+#
+#         @property
+#         def holes(self):
+#             return [GeometricEdgeLoop.get_obj_by_id(x.Id) for x in self._wrapped_obj.Holes.Items]
+#
+#         @property
+#         def points(self):
+#             return self.boundary.points
+#
+#     class GeometricVolume(geo_types['volume']):
+#
+#         @property
+#         def faces(self):
+#             if self._faces is None:
+#                 self._faces = [GeometricFace.get_obj_by_id(x.Face.Id) for x in self._wrapped_obj.Faces.Items]
+#             return self._faces
+#
+#         @faces.setter
+#         def faces(self, value):
+#             self._faces = value
+#
+#     return GeoBaseClass, GeometricLayer, GeometricVertex, GeometricEdge, GeometricEdgeLoop, GeometricFace, GeometricVolume
